# ========================
# HIGHWAY TAGS
# ========================

# Default tags to keep with highways
# Mostly based on: https://wiki.openstreetmap.org/wiki/Key:highway
highway_tags_to_keep = ["access",
                        "area",
                        "bicycle",
                        "bicycle_road",
                        "bridge",
                        "busway",
                        "cycleway",
                        "est_width",
                        "foot",
                        "footway",
                        "highway",
                        "int_ref",
                        "junction",
                        "lanes",
                        "lit",
                        "maxspeed",
                        "motorcar",
                        "motorroad",
                        "motor_vehicle",
                        "name",
                        "oneway",
                        "overtaking",
                        "path",
                        "passing_places",
                        "psv",
                        "ref",
                        "service",
                        "segregated",
                        "sidewalk",
                        "smoothness",
                        "surface",
                        "tracktype",
                        "tunnel",
                        "turn",
                        "width",
                        "winter_road",

                        # Other highway tags which are not kept by default
                        # (more tags slows down the parsing)
                        # =====================================

                        # "abutters",
                        # "driving_side",
                        # "embedded_rails",
                        # "ford",
                        # "ice_road",
                        # "incline",
                        # "mtb:scale",
                        # "mtb:scale:uphill",
                        # "mtb:scale:imba",
                        # "mtb:description",
                        # "parking:condition",
                        # "parking:lane",
                        # "sac_scale",
                        # "tactile_paving",
                        # "traffic_calming",
                        # "trail_visibility",

                        ]

amenity_tags_to_keep = ["access",
                        "amenity",
                        "area",
                        "barrier",
                        "bicycle",
                        "bridge",
                        "building",
                        "created_by",
                        "cycleway",
                        "electrified",
                        "est_width",
                        "foot",
                        "footway",
                        "gauge",
                        "height",
                        "highway",
                        "horse",
                        "int_ref",
                        "is_in",
                        "junction",
                        "landuse",
                        "lanes",
                        "layer",
                        "leisure",
                        "lit",
                        "maxspeed",
                        "motorcar",
                        "motor_vehicle",
                        "name",
                        "natural",
                        "oneway",
                        "path",
                        "place",
                        "power",
                        "psv",
                        "railway",
                        "ref",
                        "service",
                        "segregated",
                        "sidewalk",
                        "source",
                        "surface",
                        "tunnel",
                        "waterway",
                        "wetland",
                        "width",
                        "wood"]
